@@ -558,6 +558,17 @@ def diff(filename, st, et, with_file=None, latest=False):
 class GetCommand(lib.ArgumentParametersCommand):
     argument_name = "resource"
     argument_value_parameters = [
+        {
+            "resource": [lib.REDFLAGS_RESOURCE, lib.OPSFLAGS_RESOURCE],
+            "args": [
+                click.option(
+                    "--severity",
+                    lib.FLAG_SEVERITY,
+                    help="Only show flags with the given"
+                    " severity or higher.",
+                ),
+            ],
+        },
         {
             "resource": [lib.REDFLAGS_RESOURCE],
             "args": [
@@ -568,12 +579,6 @@ class GetCommand(lib.ArgumentParametersCommand):
                     help="Include redflags marked as exceptions in output."
                     " Off by default.",
                 ),
-                click.option(
-                    "--severity",
-                    lib.FLAG_SEVERITY,
-                    help="Only show redflags with the given"
-                    " severity or higher.",
-                ),
             ],
         },
     ]
@@ -639,7 +644,9 @@ class GetCommand(lib.ArgumentParametersCommand):
     "-o",
     "--output",
     default=lib.OUTPUT_DEFAULT,
-    type=click.Choice(lib.OUTPUT_CHOICES, case_sensitive=False),
+    type=click.Choice(
+        lib.OUTPUT_CHOICES + [lib.OUTPUT_WIDE], case_sensitive=False
+    ),
 )
 @click.option(
     "-f",
